@@ -11,7 +11,7 @@ from .scalar import Scalar
 
 
 def gbstr(arg):
-    """Convert arg to a string as an argument in a GraphBLAS call"""
+    """Convert arg to a string as an argument in a GraphBLAS call."""
     if arg is None:
         return "NULL"
     if isinstance(arg, TypedOpBase):
@@ -139,8 +139,8 @@ class Recorder:
     def _repr_html_(self):  # pragma: no cover
         try:
             from IPython.display import Code
-        except ImportError:
-            raise NotImplementedError()
+        except ImportError as exc:
+            raise NotImplementedError() from exc
         lines = self._get_repr_lines()
         code = Code("\n".join(lines), language="C")
         head, tail = self._repr_base_()
