@@ -7,7 +7,7 @@ from . import ffi, lib
 
 
 def libget(name):
-    """Helper to get items from GraphBLAS which might be GrB or GxB"""
+    """Helper to get items from GraphBLAS which might be GrB or GxB."""
     try:
         return getattr(lib, name)
     except AttributeError:
@@ -22,7 +22,7 @@ def libget(name):
 
 
 def wrapdoc(func_with_doc):
-    """Decorator to copy `__doc__` from a function onto the wrapped function"""
+    """Decorator to copy `__doc__` from a function onto the wrapped function."""
 
     def inner(func_wo_doc):
         func_wo_doc.__doc__ = func_with_doc.__doc__
@@ -254,7 +254,7 @@ class class_property:
         return self.member_property.__get__(obj, type)
 
     @property
-    def __set__(self):
+    def __set__(self):  # pylint: disable=unexpected-special-method-signature
         return self.member_property.__set__
 
 
@@ -326,8 +326,8 @@ def _autogenerate_code(
     begin="# Begin auto-generated code",
     end="# End auto-generated code",
 ):
-    """Super low-tech auto-code generation used by automethods.py and infixmethods.py"""
-    with open(filename) as f:
+    """Super low-tech auto-code generation used by automethods.py and infixmethods.py."""
+    with open(filename) as f:  # pragma: no branch (flaky)
         orig_text = f.read()
     if specializer:
         begin = f"{begin}: {specializer}"
@@ -347,7 +347,7 @@ def _autogenerate_code(
     new_text = orig_text
     for start, stop in reversed(boundaries):
         new_text = f"{new_text[:start]}{begin}{text}{new_text[stop:]}"
-    with open(filename, "w") as f:
+    with open(filename, "w") as f:  # pragma: no branch (flaky)
         f.write(new_text)
     import subprocess
 
