@@ -218,7 +218,6 @@ class Vector(BaseType):
 
         Examples
         --------
-
             >>> del v[1:-1]
         """
         del Updater(self, opts=opts)[keys]
@@ -231,7 +230,6 @@ class Vector(BaseType):
 
         Examples
         --------
-
         .. code-block:: python
 
             sub_v = v[[1, 3, 5]].new()
@@ -250,7 +248,6 @@ class Vector(BaseType):
 
         Examples
         --------
-
         .. code-block:: python
 
             # This makes a dense iso-value vector
@@ -263,7 +260,6 @@ class Vector(BaseType):
 
         Examples
         --------
-
         .. code-block:: python
 
             # Check if v[15] is non-empty
@@ -291,7 +287,7 @@ class Vector(BaseType):
         raise TypeError("Unable to get size of Vector with backend: {backend}")
 
     def isequal(self, other, *, check_dtype=False, **opts):
-        """Check for exact equality (same size, same structure)
+        """Check for exact equality (same size, same structure).
 
         Parameters
         ----------
@@ -389,7 +385,7 @@ class Vector(BaseType):
 
     @property
     def _nvals(self):
-        """Like nvals, but doesn't record calls"""
+        """Like nvals, but doesn't record calls."""
         n = ffi_new("GrB_Index*")
         check_status(lib.GrB_Vector_nvals(n, self.gb_obj[0]), self)
         return n[0]
@@ -454,6 +450,11 @@ class Vector(BaseType):
         sort : bool, default=True
             Whether to require sorted indices.
 
+        See Also
+        --------
+        to_dict
+        from_coo
+
         Returns
         -------
         np.ndarray[dtype=uint64] : Indices
@@ -600,7 +601,7 @@ class Vector(BaseType):
         return rv
 
     def wait(self, how="materialize"):
-        """Wait for a computation to complete or establish a "happens-before" relation
+        """Wait for a computation to complete or establish a "happens-before" relation.
 
         Parameters
         ----------
@@ -692,14 +693,14 @@ class Vector(BaseType):
         return cls.from_coo(indices, values, dtype, size=size, dup_op=dup_op, name=name)
 
     @classmethod
-    def from_coo(cls, indices, values, dtype=None, *, size=None, dup_op=None, name=None):
+    def from_coo(cls, indices, values=1.0, dtype=None, *, size=None, dup_op=None, name=None):
         """Create a new Vector from indices and values.
 
         Parameters
         ----------
         indices : list or np.ndarray
             Vector indices.
-        values : list or np.ndarray or scalar
+        values : list or np.ndarray or scalar, default 1.0
             List of values. If a scalar is provided, all values will be set to this single value.
         dtype :
             Data type of the Vector. If not provided, the values will be inspected
@@ -713,6 +714,12 @@ class Vector(BaseType):
         name : str, optional
             Name to give the Vector.
 
+        See Also
+        --------
+        from_dict
+        from_pairs
+        to_coo
+
         Returns
         -------
         Vector
@@ -744,6 +751,53 @@ class Vector(BaseType):
             w.build(indices, values, dup_op=dup_op)
         return w
 
+    @classmethod
+    def from_pairs(cls, pairs, dtype=None, *, size=None, dup_op=None, name=None):
+        """Create a new Vector from indices and values.
+
+        This transforms the data and calls ``Vector.from_coo``.
+
+        Parameters
+        ----------
+        pairs : list or iterable
+            A sequence of ``(index, value)`` pairs.
+        dtype :
+            Data type of the Vector. If not provided, the values will be inspected
+            to choose an appropriate dtype.
+        size : int, optional
+            Size of the Vector. If not provided, ``size`` is computed from
+            the maximum index found in ``pairs``.
+        dup_op : BinaryOp, optional
+            Function used to combine values if duplicate indices are found.
+            Leaving ``dup_op=None`` will raise an error if duplicates are found.
+        name : str, optional
+            Name to give the Vector.
+
+        See Also
+        --------
+        from_coo
+        from_dict
+        to_coo
+
+        Returns
+        -------
+        Vector
+        """
+        if isinstance(pairs, np.ndarray):
+            raise TypeError("pairs as NumPy array is not supported; use `Vector.from_coo` instead")
+        unzipped = list(zip(*pairs))
+        if len(unzipped) == 2:
+            indices, values = unzipped
+        elif not unzipped:
+            # Empty pairs (size should be given)
+            indices = values = unzipped
+        else:
+            raise ValueError(
+                "Each item in the pairs must have two elements (for index and value); "
+                f"got {len(unzipped)}"
+            )
+        return cls.from_coo(indices, values, dtype, size=size, dup_op=dup_op, name=name)
+
     @property
     def _carg(self):
         return self.gb_obj[0]
@@ -773,11 +827,10 @@ class Vector(BaseType):
 
         Returns
         -------
-        Vector with a structure formed as the union of the input structures
+        VectorExpression with a structure formed as the union of the input structures
 
         Examples
         --------
-
         .. code-block:: python
 
             # Method syntax
@@ -857,11 +910,10 @@ class Vector(BaseType):
 
         Returns
         -------
-        Vector with a structure formed as the intersection of the input structures
+        VectorExpression with a structure formed as the intersection of the input structures
 
         Examples
         --------
-
         .. code-block:: python
 
             # Method syntax
@@ -907,7 +959,7 @@ class Vector(BaseType):
 
     def ewise_union(self, other, op, left_default, right_default):
         """Perform element-wise computation on the union of sparse values,
-        similar to how one expects subtraction to work for sparse matrices.
+        similar to how one expects subtraction to work for sparse vectors.
 
         See the `Element-wise Union <../user_guide/operations.html#element-wise-union>`__
         section in the User Guide for more details, especially about the difference between
@@ -926,11 +978,10 @@ class Vector(BaseType):
 
         Returns
         -------
-        Vector with a structure formed as the union of the input structures
+        VectorExpression with a structure formed as the union of the input structures
 
         Examples
         --------
-
         .. code-block:: python
 
             # Method syntax
@@ -1041,11 +1092,10 @@ class Vector(BaseType):
 
         Returns
         -------
-        Vector
+        VectorExpression
 
         Examples
         --------
-
         .. code-block:: python
 
             # Method syntax
@@ -1100,11 +1150,10 @@ class Vector(BaseType):
 
         Returns
         -------
-        Vector
+        VectorExpression
 
         Examples
         --------
-
         .. code-block:: python
 
             # Method syntax
@@ -1239,19 +1288,17 @@ class Vector(BaseType):
 
         Parameters
         ----------
-        op : :class:`~graphblas.core.operator.SelectOp` or
-             :class:`~graphblas.core.operator.IndexUnaryOp`
+        op : :class:`~graphblas.core.operator.SelectOp`
             Operator to apply
         thunk :
             Scalar passed to operator
 
         Returns
         -------
-        Vector
+        VectorExpression
 
         Examples
         --------
-
         .. code-block:: python
 
             # Method syntax
@@ -1345,11 +1392,10 @@ class Vector(BaseType):
 
         Returns
         -------
-        Scalar
+        ScalarExpression
 
         Examples
         --------
-
         .. code-block:: python
 
             total << v.reduce(monoid.plus)
@@ -1390,11 +1436,10 @@ class Vector(BaseType):
 
         Returns
         -------
-        Scalar
+        ScalarExpression
 
         Examples
         --------
-
         .. code-block:: python
 
             # Method syntax
@@ -1417,6 +1462,7 @@ class Vector(BaseType):
             [self, other._as_matrix()],
             op=op,
             is_cscalar=False,
+            scalar_as_vector=True,
         )
         if self._size != other._size:
             expr.new(name="")  # incompatible shape; raise now
@@ -1434,11 +1480,10 @@ class Vector(BaseType):
 
         Returns
         -------
-        Matrix
+        MatrixExpression
 
         Examples
         --------
-
         .. code-block:: python
 
             C << v.outer(w, op=binary.times)
@@ -1485,11 +1530,10 @@ class Vector(BaseType):
 
         Returns
         -------
-        Vector
+        VectorExpression
 
         Examples
         --------
-
         .. code-block:: python
 
             w = v.reposition(20).new()
@@ -1511,7 +1555,7 @@ class Vector(BaseType):
             "reposition",
             None,
             [self, _reposition, (indices, chunk)],  # [*expr_args, func, args]
-            expr_repr="{0.name}.reposition(%d)" % offset,
+            expr_repr=f"{{0.name}}.reposition({offset})",
             size=size,
             dtype=self.dtype,
         )
@@ -1606,7 +1650,11 @@ class Vector(BaseType):
                 else:
                     cfunc_name = "GrB_Vector_assign"
                     mask = _vanilla_subassign_mask(self, mask, idx, replace, opts)
-                expr_repr = "[[{2._expr_name} elements]](%s) = {0.name}" % mask.name
+                expr_repr = (
+                    "[[{2._expr_name} elements]]"
+                    f"({mask.name})"  # fmt: skip
+                    " = {0.name}"
+                )
             else:
                 # v(m)[I] << w
                 # v[I] << w
@@ -1641,7 +1689,7 @@ class Vector(BaseType):
                                     vals = Vector.from_coo(
                                         np.arange(shape[0]), values, dtype, size=shape[0]
                                     )
-                            except Exception:
+                            except Exception:  # pragma: no cover (safety)
                                 vals = None
                             else:
                                 if dtype.np_type.subdtype is not None:
@@ -1698,7 +1746,11 @@ class Vector(BaseType):
                     else:
                         cfunc_name = "GrB_Vector_assign_Scalar"
                         mask = _vanilla_subassign_mask(self, mask, idx, replace, opts)
-                expr_repr = "[[{2._expr_name} elements]](%s) = {0._expr_name}" % mask.name
+                expr_repr = (
+                    "[[{2._expr_name} elements]]"
+                    f"({mask.name})"  # fmt: skip
+                    " = {0._expr_name}"
+                )
             else:
                 # v(m)[I] << c
                 # v[I] << c
@@ -1746,6 +1798,12 @@ class Vector(BaseType):
         name : str, optional
             Name to give the Vector.
 
+        See Also
+        --------
+        from_coo
+        from_pairs
+        to_dict
+
         Returns
         -------
         Vector
@@ -1763,7 +1821,12 @@ class Vector(BaseType):
         return cls.from_coo(indices, values, dtype, size=size, name=name)
 
     def to_dict(self):
-        """Return Vector as a dict in the form ``{index: val}``
+        """Return Vector as a dict in the form ``{index: val}``.
+
+        See Also
+        --------
+        to_coo
+        from_dict
 
         Returns
         -------
@@ -1851,6 +1914,12 @@ class VectorExpression(BaseExpression):
     def shape(self):
         return (self._size,)
 
+    @wrapdoc(Vector.dup)
+    def dup(self, dtype=None, *, clear=False, mask=None, name=None, **opts):
+        if clear:
+            return Vector(self.dtype if dtype is None else dtype, self.size, name=name)
+        return self._new(dtype, mask, name)
+
     # Begin auto-generated code: Vector
     _get_value = automethods._get_value
     S = wrapdoc(Vector.S)(property(automethods.S))
@@ -1878,8 +1947,7 @@ class VectorExpression(BaseExpression):
     inner = wrapdoc(Vector.inner)(property(automethods.inner))
     isclose = wrapdoc(Vector.isclose)(property(automethods.isclose))
     isequal = wrapdoc(Vector.isequal)(property(automethods.isequal))
-    name = wrapdoc(Vector.name)(property(automethods.name))
-    name = name.setter(automethods._set_name)
+    name = wrapdoc(Vector.name)(property(automethods.name)).setter(automethods._set_name)
     nvals = wrapdoc(Vector.nvals)(property(automethods.nvals))
     outer = wrapdoc(Vector.outer)(property(automethods.outer))
     reduce = wrapdoc(Vector.reduce)(property(automethods.reduce))
@@ -1887,6 +1955,8 @@ class VectorExpression(BaseExpression):
     select = wrapdoc(Vector.select)(property(automethods.select))
     if backend == "suitesparse":
         ss = wrapdoc(Vector.ss)(property(automethods.ss))
+    else:
+        ss = Vector.__dict__["ss"]  # raise if used
     to_coo = wrapdoc(Vector.to_coo)(property(automethods.to_coo))
     to_dict = wrapdoc(Vector.to_dict)(property(automethods.to_dict))
     to_values = wrapdoc(Vector.to_values)(property(automethods.to_values))
@@ -1926,6 +1996,14 @@ class VectorIndexExpr(AmbiguousAssignOrExtract):
     def shape(self):
         return (self._size,)
 
+    @wrapdoc(Vector.dup)
+    def dup(self, dtype=None, *, clear=False, mask=None, name=None, **opts):
+        if clear:
+            if dtype is None:
+                dtype = self.dtype
+            return self.output_type(dtype, *self.shape, name=name)
+        return self.new(dtype, mask=mask, name=name, **opts)
+
     # Begin auto-generated code: Vector
     _get_value = automethods._get_value
     S = wrapdoc(Vector.S)(property(automethods.S))
@@ -1953,8 +2031,7 @@ class VectorIndexExpr(AmbiguousAssignOrExtract):
     inner = wrapdoc(Vector.inner)(property(automethods.inner))
     isclose = wrapdoc(Vector.isclose)(property(automethods.isclose))
     isequal = wrapdoc(Vector.isequal)(property(automethods.isequal))
-    name = wrapdoc(Vector.name)(property(automethods.name))
-    name = name.setter(automethods._set_name)
+    name = wrapdoc(Vector.name)(property(automethods.name)).setter(automethods._set_name)
     nvals = wrapdoc(Vector.nvals)(property(automethods.nvals))
     outer = wrapdoc(Vector.outer)(property(automethods.outer))
     reduce = wrapdoc(Vector.reduce)(property(automethods.reduce))
@@ -1962,6 +2039,8 @@ class VectorIndexExpr(AmbiguousAssignOrExtract):
     select = wrapdoc(Vector.select)(property(automethods.select))
     if backend == "suitesparse":
         ss = wrapdoc(Vector.ss)(property(automethods.ss))
+    else:
+        ss = Vector.__dict__["ss"]  # raise if used
     to_coo = wrapdoc(Vector.to_coo)(property(automethods.to_coo))
     to_dict = wrapdoc(Vector.to_dict)(property(automethods.to_dict))
     to_values = wrapdoc(Vector.to_values)(property(automethods.to_values))
@@ -1989,4 +2068,4 @@ utils._output_types[VectorIndexExpr] = Vector
 utils._output_types[VectorExpression] = Vector
 
 # Import matrix to import infix to import infixmethods, which has side effects
-from . import matrix  # noqa isort:skip
+from . import matrix  # noqa: E402, F401 isort:skip
