@@ -3,7 +3,7 @@ from collections.abc import Mapping
 from ..core import ffi, lib
 from ..core.base import _expect_type
 from ..core.matrix import Matrix, TransposedMatrix
-from ..core.scalar import Scalar
+from ..core.scalar import _as_scalar
 from ..core.ss.config import BaseConfig
 from ..core.ss.matrix import _concat_mn
 from ..core.vector import Vector
@@ -12,7 +12,7 @@ from ..exceptions import _error_code_lookup
 
 
 class _graphblas_ss:
-    """Used in `_expect_type`"""
+    """Used in `_expect_type`."""
 
 
 _graphblas_ss.__name__ = "graphblas.ss"
@@ -21,7 +21,7 @@ _graphblas_ss = _graphblas_ss()
 
 def diag(x, k=0, dtype=None, *, name=None, **opts):
     """
-    GxB_Matrix_diag, GxB_Vector_diag
+    GxB_Matrix_diag, GxB_Vector_diag.
 
     Extract a diagonal Vector from a Matrix, or construct a diagonal Matrix
     from a Vector.  Unlike ``Matrix.diag`` and ``Vector.diag``, this function
@@ -47,8 +47,7 @@ def diag(x, k=0, dtype=None, *, name=None, **opts):
     x = _expect_type(
         _graphblas_ss, x, (Matrix, TransposedMatrix, Vector), within="diag", argname="x"
     )
-    if type(k) is not Scalar:
-        k = Scalar.from_value(k, INT64, is_cscalar=True, name="")
+    k = _as_scalar(k, INT64, is_cscalar=True)
     if dtype is None:
         dtype = x.dtype
     typ = type(x)
@@ -58,11 +57,9 @@ def diag(x, k=0, dtype=None, *, name=None, **opts):
         rv.ss.build_diag(x, k)
     else:
         if k.value < 0:
-            size = min(x._nrows + k.value, x._ncols)
+            size = max(0, min(x._nrows + k.value, x._ncols))
         else:
-            size = min(x._ncols - k.value, x._nrows)
-        if size < 0:
-            size = 0
+            size = max(0, min(x._ncols - k.value, x._nrows))
         rv = Vector(dtype, size=size, name=name)
         rv.ss.build_diag(x, k, **opts)
     return rv
@@ -70,7 +67,7 @@ def diag(x, k=0, dtype=None, *, name=None, **opts):
 
 def concat(tiles, dtype=None, *, name=None, **opts):
     """
-    GxB_Matrix_concat
+    GxB_Matrix_concat.
 
     Concatenate a 2D list of Matrix objects into a new Matrix, or a 1D list of
     Vector objects into a new Vector.  To concatenate into existing objects,
@@ -106,7 +103,7 @@ def concat(tiles, dtype=None, *, name=None, **opts):
 
 
 class GlobalConfig(BaseConfig):
-    """Get and set global configuration options for SuiteSparse:GraphBLAS
+    """Get and set global configuration options for SuiteSparse:GraphBLAS.
 
     See SuiteSparse:GraphBLAS documentation for more details.
 
