@@ -5,20 +5,30 @@ import pytest
 
 import graphblas as gb
 from graphblas import Matrix, dtypes
+from graphblas.exceptions import GraphblasException
 
 try:
     import networkx as nx
 except ImportError:  # pragma: no cover (import)
     nx = None
+
 try:
     import scipy.sparse as ss
 except ImportError:  # pragma: no cover (import)
     ss = None
 
 try:
-    import awkward._v2 as ak
+    import sparse
 except ImportError:  # pragma: no cover (import)
-    ak = None
+    sparse = None
+
+try:
+    import awkward._v2 as ak
+except ImportError:
+    try:
+        import awkward as ak
+    except ImportError:  # pragma: no cover (import)
+        ak = None
 
 
 suitesparse = gb.backend == "suitesparse"
@@ -86,7 +96,7 @@ def test_matrix_to_from_numpy():
     with pytest.raises(ValueError, match="Invalid format"):
         gb.io.to_scipy_sparse(M, "bad format")
 
-    with pytest.raises(gb.exceptions.GraphblasException, match="ndim must be"):
+    with pytest.raises(GraphblasException, match="ndim must be"):
         gb.io.from_numpy(np.array([[[1.0, 0.0], [2.0, 3.7]]]))
 
 
@@ -308,7 +318,7 @@ def test_matrix_market_sparse_duplicates():
 def test_scipy_sparse():
     a = np.arange(12).reshape(3, 4)
     for a in [np.arange(12).reshape(3, 4), np.ones((3, 4)), np.zeros((3, 4))]:
-        for fmt in {"bsr", "csr", "csc", "coo", "lil", "dia", "dok"}:
+        for fmt in ["bsr", "csr", "csc", "coo", "lil", "dia", "dok"]:
             sa = getattr(ss, f"{fmt}_array")(a)
             A = gb.io.from_scipy_sparse(sa)
             for M in [A, A.T.new().T]:
@@ -369,13 +379,13 @@ def test_awkward_errors():
     m = gb.Matrix.from_coo([0, 0, 3, 5], [1, 4, 0, 2], [1, 1, 1, 1], nrows=7, ncols=6)
     with pytest.raises(ValueError, match="Missing parameters"):
         gb.io.from_awkward(ak.Array([1, 2, 3]))
+    kv = gb.io.to_awkward(v)
+    kv = ak.with_parameter(kv, "format", "csr")
     with pytest.raises(ValueError, match="Invalid format for Vector"):
-        kv = gb.io.to_awkward(v)
-        kv = ak.with_parameter(kv, "format", "csr")
         gb.io.from_awkward(kv)
+    km = gb.io.to_awkward(m)
+    km = ak.with_parameter(km, "format", "dcsr")
     with pytest.raises(ValueError, match="Invalid format for Matrix"):
-        km = gb.io.to_awkward(m)
-        km = ak.with_parameter(km, "format", "dcsr")
         gb.io.from_awkward(km)
     with pytest.raises(ValueError, match="Invalid format for Vector"):
         gb.io.to_awkward(v, format="csr")
@@ -383,3 +393,50 @@ def test_awkward_errors():
         gb.io.to_awkward(m, format="dcsr")
     with pytest.raises(TypeError):
         gb.io.to_awkward(gb.Scalar.from_value(5))
+
+
+@pytest.mark.skipif("not sparse")
+def test_vector_to_from_pydata_sparse():
+    coords = np.array([0, 1, 2, 3, 4], dtype="int64")
+    data = np.array([10, 20, 30, 40, 50], dtype="int64")
+    s = sparse.COO(coords, data, shape=(5,))
+    v = gb.io.from_pydata_sparse(s)
+    assert v.isequal(gb.Vector.from_coo(coords, data, dtype=dtypes.INT64), check_dtype=True)
+
+    t = gb.io.to_pydata_sparse(v)
+    assert t == s
+
+
+@pytest.mark.skipif("not sparse")
+def test_matrix_to_from_pydata_sparse():
+    coords = np.array([[0, 1, 2, 3, 4], [0, 1, 2, 3, 4]], dtype="int64")
+    data = np.array([10, 20, 30, 40, 50], dtype="int64")
+    s = sparse.COO(coords, data, shape=(5, 5))
+    v = gb.io.from_pydata_sparse(s)
+    assert v.isequal(gb.Matrix.from_coo(*coords, data, dtype=dtypes.INT64), check_dtype=False)
+
+    t = gb.io.to_pydata_sparse(v)
+    assert t == s
+
+    # test ndim
+    e = sparse.random(shape=(5, 5, 5), density=0)
+    with pytest.raises(GraphblasException):
+        gb.io.from_pydata_sparse(e)
+
+    # test GCXS array conversion
+    indptr = np.array([0, 2, 3, 6], dtype="int64")
+    indices = np.array([0, 2, 2, 0, 1, 2], dtype="int64")
+    data = np.array([1, 2, 3, 4, 5, 6], dtype="int64")
+
+    g = sparse.GCXS((data, indices, indptr), shape=(3, 3), compressed_axes=[0])
+    w = gb.io.from_pydata_sparse(g)
+    coords = g.asformat("coo").coords
+    data = g.asformat("coo").data
+    assert w.isequal(gb.Matrix.from_coo(*coords, data, dtype=dtypes.INT64), check_dtype=False)
+
+    r = gb.io.to_pydata_sparse(w, format="gcxs")
+    assert r == g
+    with pytest.raises(ValueError, match="format"):
+        gb.io.to_pydata_sparse(w, format="badformat")
+    with pytest.raises(TypeError, match="sparse.pydata"):
+        gb.io.from_pydata_sparse(w)
