@@ -4,7 +4,7 @@ import numpy as np
 import pytest
 
 import graphblas as gb
-from graphblas import agg, binary, dtypes, indexunary, monoid, op, select, semiring, unary
+from graphblas import agg, backend, binary, dtypes, indexunary, monoid, op, select, semiring, unary
 from graphblas.core import lib, operator
 from graphblas.core.operator import BinaryOp, IndexUnaryOp, Monoid, Semiring, UnaryOp, get_semiring
 from graphblas.dtypes import (
@@ -27,6 +27,8 @@ if dtypes._supports_complex:
 
 from graphblas import Matrix, Vector  # isort:skip (for dask-graphblas)
 
+suitesparse = backend == "suitesparse"
+
 
 def orig_types(op):
     return op.types.keys() - op.coercions.keys()
@@ -49,15 +51,17 @@ def test_op_repr():
 def test_unaryop():
     assert unary.ainv["INT32"].gb_obj == lib.GrB_AINV_INT32
     assert unary.ainv[dtypes.UINT16].gb_obj == lib.GrB_AINV_UINT16
-    assert orig_types(unary.positioni) == {INT32, INT64}
-    assert orig_types(unary.positionj1) == {INT32, INT64}
+    if suitesparse:
+        assert orig_types(unary.ss.positioni) == {INT32, INT64}
+        assert orig_types(unary.ss.positionj1) == {INT32, INT64}
 
 
 def test_binaryop():
     assert binary.plus["INT32"].gb_obj == lib.GrB_PLUS_INT32
     assert binary.plus[dtypes.UINT16].gb_obj == lib.GrB_PLUS_UINT16
-    assert orig_types(binary.firsti) == {INT32, INT64}
-    assert orig_types(binary.secondj1) == {INT32, INT64}
+    if suitesparse:
+        assert orig_types(binary.ss.firsti) == {INT32, INT64}
+        assert orig_types(binary.ss.secondj1) == {INT32, INT64}
 
 
 def test_monoid():
@@ -68,18 +72,22 @@ def test_monoid():
 def test_semiring():
     assert semiring.min_plus["INT32"].gb_obj == lib.GrB_MIN_PLUS_SEMIRING_INT32
     assert semiring.min_plus[dtypes.UINT16].gb_obj == lib.GrB_MIN_PLUS_SEMIRING_UINT16
-    assert orig_types(semiring.min_firsti) == {INT32, INT64}
+    if suitesparse:
+        assert orig_types(semiring.ss.min_firsti) == {INT32, INT64}
 
 
 def test_agg():
     assert repr(agg.count) == "agg.count"
     assert repr(agg.count["INT32"]) == "agg.count[INT32]"
+    if suitesparse:
+        assert repr(agg.ss.first) == "agg.ss.first"
     assert "INT64" in agg.sum_of_inverses
     assert agg.sum_of_inverses["INT64"].return_type == FP64
     assert "BOOL" not in agg.sum_of_inverses
     with pytest.raises(KeyError, match="BOOL"):
         agg.sum_of_inverses["BOOL"]
     assert agg.varp["INT64"].return_type == "FP64"
+    assert set(dir(agg)).issuperset({"count", "mean", "ss"})
 
 
 def test_find_opclass_unaryop():
@@ -129,7 +137,7 @@ def test_get_typed_op():
     )
     with pytest.raises(ValueError, match="Unknown binary or aggregator"):
         operator.get_typed_op("bad_op_name", dtypes.INT64, kind="binary|aggregator")
-    with pytest.raises(Exception):
+    with pytest.raises(AttributeError):
         # get_typed_op expects dtypes to already be dtypes
         operator.get_typed_op(binary.plus, dtypes.INT64, "bad dtype")
 
@@ -246,11 +254,11 @@ def test_binaryop_parameterized():
     with pytest.raises(TypeError, match="UDF argument must be a function"):
         BinaryOp.register_new("bad", object())
     assert not hasattr(binary, "bad")
+
+    def bad(x, y):  # pragma: no cover (numba)
+        return v
+
     with pytest.raises(UdfParseError, match="Unable to parse function using Numba"):
-
-        def bad(x, y):  # pragma: no cover (numba)
-            return v
-
         BinaryOp.register_new("bad", bad)
 
     def my_add(x, y):
@@ -566,6 +574,7 @@ def test_monoid_udf():
         Monoid.register_anonymous(binary.plus_plus_one, {"BOOL": -1})
 
 
+@pytest.mark.slow
 def test_semiring_udf():
     def plus_plus_two(x, y):
         return x + y + 2  # pragma: no cover (numba)
@@ -707,16 +716,31 @@ def test_op_namespace():
         for key, val in vars(select).items()
         if isinstance(val, (operator.OpBase, operator.ParameterizedUdf))
     }
-    assert not unarynames - opnames, unarynames - opnames
-    assert not binarynames - opnames, binarynames - opnames
+    extra_unary = unarynames - opnames - unary._deprecated.keys()
+    assert not extra_unary
+    extra_binary = binarynames - opnames - binary._deprecated.keys()
+    assert not extra_binary
     assert not monoidnames - opnames, monoidnames - opnames
-    assert not semiringnames - opnames, semiringnames - opnames
-    assert not opnames - (unarynames | binarynames | monoidnames | semiringnames)
+    extra_semiring = semiringnames - opnames - semiring._deprecated.keys()
+    assert not extra_semiring
+    extra_ops = (
+        opnames - (unarynames | binarynames | monoidnames | semiringnames) - op._deprecated.keys()
+    )
+    assert not extra_ops
     # These are not part of the `op` namespace
     assert indexunarynames - opnames == indexunarynames, indexunarynames - opnames
     assert selectnames - opnames == selectnames, selectnames - opnames
 
 
+@pytest.mark.slow
+def test_binaryop_attributes_numpy():
+    # Some coverage from this test depends on order of tests
+    assert binary.numpy.add[int].monoid is monoid.numpy.add[int]
+    assert binary.numpy.subtract[int].monoid is None
+    assert binary.numpy.add.monoid is monoid.numpy.add
+    assert binary.numpy.subtract.monoid is None
+
+
 @pytest.mark.slow
 def test_binaryop_attributes():
     assert binary.plus[int].monoid is monoid.plus[int]
@@ -724,11 +748,6 @@ def test_binaryop_attributes():
     assert binary.plus.monoid is monoid.plus
     assert binary.minus.monoid is None
 
-    assert binary.numpy.add[int].monoid is monoid.numpy.add[int]
-    assert binary.numpy.subtract[int].monoid is None
-    assert binary.numpy.add.monoid is monoid.numpy.add
-    assert binary.numpy.subtract.monoid is None
-
     def plus(x, y):
         return x + y  # pragma: no cover (numba)
 
@@ -902,12 +921,16 @@ def test_get_semiring():
 def test_create_semiring():
     # stress test / sanity check
     monoid_names = {x for x in dir(monoid) if not x.startswith("_")}
-    binary_names = {x for x in dir(binary) if not x.startswith("_")}
+    binary_names = {x for x in dir(binary) if not x.startswith("_") and x != "ss"}
     for monoid_name, binary_name in itertools.product(monoid_names, binary_names):
         cur_monoid = getattr(monoid, monoid_name)
         if not isinstance(cur_monoid, Monoid):
             continue
-        cur_binary = getattr(binary, binary_name)
+        cur_binary = (
+            getattr(binary, binary_name)
+            if binary_name not in binary._deprecated
+            else binary._deprecated[binary_name]
+        )
         if not isinstance(cur_binary, BinaryOp):
             continue
         Semiring.register_anonymous(cur_monoid, cur_binary)
@@ -928,7 +951,8 @@ def test_commutes():
     assert semiring.plus_times.is_commutative
     assert semiring.any_first.commutes_to is semiring.any_second
     assert semiring.plus_times.is_commutative
-    assert semiring.min_secondi.commutes_to is semiring.min_firstj
+    if suitesparse:
+        assert semiring.ss.min_secondi.commutes_to is semiring.ss.min_firstj
     assert semiring.plus_pow.commutes_to is semiring.plus_rpow
     assert not semiring.plus_pow.is_commutative
     assert binary.isclose.commutes_to is binary.isclose
@@ -954,7 +978,8 @@ def test_commutes():
     assert semiring.plus_times[int].is_commutative
     assert semiring.any_first[int].commutes_to is semiring.any_second[int]
     assert semiring.plus_times[int].is_commutative
-    assert semiring.min_secondi[int].commutes_to is semiring.min_firstj[int]
+    if suitesparse:
+        assert semiring.ss.min_secondi[int].commutes_to is semiring.ss.min_firstj[int]
     assert semiring.plus_pow[int].commutes_to is semiring.plus_rpow[int]
     assert not semiring.plus_pow[int].is_commutative
     assert binary.isclose(0.1)[int].commutes_to is binary.isclose(0.1)[int]
@@ -968,7 +993,12 @@ def test_commutes():
     # Stress test (this can create extra semirings)
     names = dir(semiring)
     for name in names:
-        val = getattr(semiring, name)
+        if name in semiring._deprecated:
+            val = semiring._deprecated[name]
+        elif name == "ss":
+            continue
+        else:
+            val = getattr(semiring, name)
         if not hasattr(val, "commutes_to"):
             continue
         assert val.commutes_to is None or isinstance(val.commutes_to, type(val))
@@ -1054,34 +1084,33 @@ def test_lazy_op():
     assert isinstance(unary.misc.lazy, UnaryOp)
     with pytest.raises(AttributeError):
         unary.misc.bad
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match="Unknown unary string:"):
         unary.from_string("misc.lazy.badpath")
     assert op.from_string("lazy") is unary.lazy
     assert op.from_string("numpy.lazy") is unary.numpy.lazy
 
 
 def test_positional():
-    assert unary.positioni.is_positional
-    assert unary.positioni1[int].is_positional
-    assert unary.positionj1.is_positional
-    assert unary.positionj[float].is_positional
     assert not unary.exp.is_positional
     assert not unary.abs[bool].is_positional
-
-    assert binary.firsti.is_positional
-    assert binary.secondj1[int].is_positional
     assert not binary.plus.is_positional
     assert not binary.minus[float].is_positional
-
     assert not monoid.plus.is_positional
     assert not monoid.plus[int].is_positional
-
-    assert semiring.any_firsti.is_positional
-    assert semiring.any_secondj[int].is_positional
     assert not semiring.any_first.is_positional
     assert not semiring.any_second[int].is_positional
+    if suitesparse:
+        assert unary.ss.positioni.is_positional
+        assert unary.ss.positioni1[int].is_positional
+        assert unary.ss.positionj1.is_positional
+        assert unary.ss.positionj[float].is_positional
+        assert binary.ss.firsti.is_positional
+        assert binary.ss.secondj1[int].is_positional
+        assert semiring.ss.any_firsti.is_positional
+        assert semiring.ss.any_secondj[int].is_positional
 
 
+@pytest.mark.slow
 def test_udt():
     record_dtype = np.dtype([("x", np.bool_), ("y", np.float64)], align=True)
     udt = dtypes.register_new("TestUDT", record_dtype)
@@ -1103,9 +1132,9 @@ def test_udt():
     assert udt in udt_identity
     assert int in udt_identity
     assert operator.get_typed_op(udt_identity, udt) is udt_identity[udt]
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match="Unknown dtype:"):
         assert "badname" in binary.eq
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match="Unknown dtype:"):
         assert "badname" in udt_identity
 
     def _udt_getx(val):
@@ -1163,9 +1192,10 @@ def test_udt():
     expected = Vector(int, size=v.size)
     expected(result.S) << 1
     assert result.isequal(expected)
-    result = v.apply(gb.unary.positioni).new()
-    expected = expected.apply(gb.unary.positioni).new()
-    assert result.isequal(expected)
+    if suitesparse:
+        result = v.apply(gb.unary.ss.positioni).new()
+        expected = expected.apply(gb.unary.ss.positioni).new()
+        assert result.isequal(expected)
 
     result = indexunary.rowindex(v).new()
     assert result.isequal(Vector.from_coo([0, 1, 2], [0, 1, 2]))
@@ -1182,17 +1212,18 @@ def test_udt():
     assert udt not in badunary
     assert int not in badunary
 
-    def badfunc(x, y):  # pragma: no cover (numba)
+    def badfunc2(x, y):  # pragma: no cover (numba)
         return BreakCompile(x)
 
-    badbinary = BinaryOp.register_anonymous(badfunc, is_udt=True)
+    badbinary = BinaryOp.register_anonymous(badfunc2, is_udt=True)
     assert udt not in badbinary
     assert int not in badbinary
 
     assert binary.first[udt].return_type is udt
     assert binary.first[udt].commutes_to is binary.second[udt]
-    assert semiring.any_firsti[int].commutes_to is semiring.any_secondj[int]
-    assert semiring.any_firsti[udt].commutes_to is semiring.any_secondj[udt]
+    if suitesparse:
+        assert semiring.ss.any_firsti[int].commutes_to is semiring.ss.any_secondj[int]
+        assert semiring.ss.any_firsti[udt].commutes_to is semiring.ss.any_secondj[udt]
 
     assert binary.second[udt].type is udt
     assert binary.second[udt].type2 is udt
@@ -1213,10 +1244,13 @@ def test_dir():
 def test_semiring_commute_exists():
     from .conftest import orig_semirings
 
-    vals = {getattr(semiring, key) for key in orig_semirings}
+    vals = {
+        semiring._deprecated[key] if key in semiring._deprecated else getattr(semiring, key)
+        for key in orig_semirings
+    }
     missing = set()
     for key in orig_semirings:
-        val = getattr(semiring, key)
+        val = semiring._deprecated[key] if key in semiring._deprecated else getattr(semiring, key)
         commutes_to = val.commutes_to
         if commutes_to is not None and commutes_to not in vals:  # pragma: no cover (debug)
             missing.add(commutes_to.name)
@@ -1227,10 +1261,13 @@ def test_semiring_commute_exists():
 def test_binaryop_commute_exists():
     from .conftest import orig_binaryops
 
-    vals = {getattr(binary, key) for key in orig_binaryops}
+    vals = {
+        binary._deprecated[key] if key in binary._deprecated else getattr(binary, key)
+        for key in orig_binaryops
+    }
     missing = set()
     for key in orig_binaryops:
-        val = getattr(binary, key)
+        val = binary._deprecated[key] if key in binary._deprecated else getattr(binary, key)
         commutes_to = val.commutes_to
         if commutes_to is not None and commutes_to not in vals:  # pragma: no cover (debug)
             missing.add(commutes_to.name)
@@ -1255,3 +1292,38 @@ def test_builtins():
     v1(max) << v2
     expected = Vector.from_coo([0, 1, 2], [3, 2, 3])
     assert v1.isequal(expected)
+
+
+def test_op_ss():
+    if suitesparse:
+        gb.unary.ss.positioni
+        gb.binary.ss.firsti
+        gb.semiring.ss.max_secondj
+        gb.op.ss.positionj
+        gb.agg.ss.argmin
+    else:
+        with pytest.raises(AttributeError, match="suitesparse"):
+            gb.unary.ss
+        with pytest.raises(AttributeError, match="suitesparse"):
+            gb.binary.ss
+        with pytest.raises(AttributeError, match="suitesparse"):
+            gb.semiring.ss
+        with pytest.raises(AttributeError, match="suitesparse"):
+            gb.op.ss
+        with pytest.raises(AttributeError, match="suitesparse"):
+            gb.agg.ss
+
+
+def test_deprecated():
+    with pytest.warns(DeprecationWarning, match="please use"):
+        gb.unary.erf
+    with pytest.warns(DeprecationWarning, match="please use"):
+        gb.unary.positioni
+    with pytest.warns(DeprecationWarning, match="please use"):
+        gb.binary.firsti
+    with pytest.warns(DeprecationWarning, match="please use"):
+        gb.semiring.min_firsti
+    with pytest.warns(DeprecationWarning, match="please use"):
+        gb.op.secondj
+    with pytest.warns(DeprecationWarning, match="please use"):
+        gb.agg.argmin
