@@ -2,6 +2,7 @@ import inspect
 import itertools
 import pickle
 import sys
+import types
 import weakref
 
 import numpy as np
@@ -162,6 +163,12 @@ def test_from_coo_scalar():
             u.ss.iso_value
 
 
+def test_from_coo_default_values():
+    u = Vector.from_coo([1, 3])
+    v = Vector.from_coo([1, 3], [1.0, 1.0])
+    assert v.isequal(u, check_dtype=True)
+
+
 def test_clear(v):
     v.clear()
     assert v.nvals == 0
@@ -452,10 +459,12 @@ def test_extract_fancy_scalars(v):
     assert s.dtype == dtypes.FP64
 
     t = Scalar(float)
-    with pytest.raises(TypeError, match="is not supported"):
-        t(accum=binary.plus) << s
-    with pytest.raises(TypeError, match="is not supported"):
-        t(accum=binary.plus) << 1
+    # with pytest.raises(TypeError, match="is not supported"):
+    t(accum=binary.plus) << s  # Now okay
+    assert t == 1.0
+    # with pytest.raises(TypeError, match="is not supported"):
+    t(accum=binary.plus) << 1  # Now okay
+    assert t == 2.0
     with pytest.raises(TypeError, match="Mask not allowed for Scalars"):
         t(mask=t) << s
 
@@ -467,8 +476,12 @@ def test_extract_fancy_scalars(v):
     t = Scalar(float)
     t() << v[1]
     assert t.value == 1.0
-    with pytest.raises(TypeError, match="Scalar accumulation with extract element"):
-        t(accum=binary.plus) << v[0]
+    # with pytest.raises(TypeError, match="Scalar accumulation with extract element"):
+    with pytest.raises(TypeError, match="autocompute"):
+        t(accum=binary.plus) << v[1]  # Now okay, but autocomputes
+    with gb.config.set(autocompute=True):
+        t(accum=binary.plus) << v[1]  # Now okay, but autocomputes
+    assert t == 2.0
 
 
 def test_extract_negative_indices(v):
@@ -731,6 +744,9 @@ def test_select(v):
     w7 = v.select("==").new()
     expected = Vector.from_coo([6], 0)
     assert w7.isequal(expected)
+    w8 = select.index(v >= 4).new()
+    expected = Vector.from_coo([4, 6], [2, 0], size=7)
+    assert w8.isequal(expected)
 
 
 @autocompute
@@ -791,7 +807,7 @@ def test_indexunary_udf(v):
     indexunary.register_new("twox_minusthunk", twox_minusthunk)
     assert hasattr(indexunary, "twox_minusthunk")
     assert not hasattr(select, "twox_minusthunk")
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match="SelectOp must have BOOL return type"):
         select.register_anonymous(twox_minusthunk)
     with pytest.raises(TypeError, match="must be a function"):
         select.register_anonymous(object())
@@ -858,7 +874,7 @@ def test_reduce_empty():
     assert w.reduce(agg.sum, allow_empty=True).new().is_empty
     assert w.reduce(agg.sum, allow_empty=False).new() == 0
     assert w.reduce(agg.mean, allow_empty=True).new().is_empty
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match="allow_empty=False not allowed when using Aggregators"):
         w.reduce(agg.mean, allow_empty=False)
 
 
@@ -905,47 +921,50 @@ def test_reduce_agg(v):
     assert s.is_empty
 
 
+@pytest.mark.skipif("not suitesparse")
 def test_reduce_agg_argminmax(v):
-    assert v.reduce(agg.argmin).new() == 6
-    assert v.reduce(agg.argmax).new() == 4
+    assert v.reduce(agg.ss.argmin).new() == 6
+    assert v.reduce(agg.ss.argmax).new() == 4
 
     silly = agg.Aggregator(
         "silly",
-        composite=[agg.argmin, agg.argmax],
+        composite=[agg.ss.argmin, agg.ss.argmax],
         finalize=lambda x, y, opts: binary.plus(x & y),
-        types=[agg.argmin],
+        types=[agg.ss.argmin],
     )
     s = v.reduce(silly).new()
     assert s == 10
 
 
+@pytest.mark.skipif("not suitesparse")
 def test_reduce_agg_firstlast(v):
     empty = Vector(int, size=4)
-    assert empty.reduce(agg.first).new().is_empty
-    assert empty.reduce(agg.last).new().is_empty
+    assert empty.reduce(agg.ss.first).new().is_empty
+    assert empty.reduce(agg.ss.last).new().is_empty
 
-    assert v.reduce(agg.first).new() == 1
-    assert v.reduce(agg.last).new() == 0
+    assert v.reduce(agg.ss.first).new() == 1
+    assert v.reduce(agg.ss.last).new() == 0
 
     silly = agg.Aggregator(
         "silly",
-        composite=[agg.first, agg.last],
+        composite=[agg.ss.first, agg.ss.last],
         finalize=lambda x, y, opts: binary.plus(x & y),
-        types=[agg.first],
+        types=[agg.ss.first],
     )
     s = v.reduce(silly).new()
     assert s == 1
 
 
+@pytest.mark.skipif("not suitesparse")
 def test_reduce_agg_firstlast_index(v):
-    assert v.reduce(agg.first_index).new() == 1
-    assert v.reduce(agg.last_index).new() == 6
+    assert v.reduce(agg.ss.first_index).new() == 1
+    assert v.reduce(agg.ss.last_index).new() == 6
 
     silly = agg.Aggregator(
         "silly",
-        composite=[agg.first_index, agg.last_index],
+        composite=[agg.ss.first_index, agg.ss.last_index],
         finalize=lambda x, y, opts: binary.plus(x & y),
-        types=[agg.first_index],
+        types=[agg.ss.first_index],
     )
     s = v.reduce(silly).new()
     assert s == 7
@@ -1272,7 +1291,6 @@ def test_ss_import_export_auto(v, do_iso, methods):
             else:
                 d = v2.ss.unpack(format, sort=sort, raw=raw)
             if in_method == "import":
-                import_func = getattr(Vector.ss, f"import_{import_name}")
 
                 def import_func(x, import_name, **kwargs):
                     return getattr(Vector.ss, f"import_{import_name}")(**kwargs)
@@ -1299,7 +1317,7 @@ def test_ss_import_export_auto(v, do_iso, methods):
         w(w.S) << 1
     w_orig = w.dup()
     format = "full"
-    for (raw, import_format, give_ownership, take_ownership, import_name,) in itertools.product(
+    for (raw, import_format, give_ownership, take_ownership, import_name) in itertools.product(
         [False, True],
         [format, None],
         [False, True],
@@ -1313,22 +1331,22 @@ def test_ss_import_export_auto(v, do_iso, methods):
             d = w2.ss.unpack(format, raw=raw)
         if in_method == "import":
 
-            def import_func(x, import_name, **kwargs):
+            def import_func2(x, import_name, **kwargs):
                 return getattr(Vector.ss, f"import_{import_name}")(**kwargs)
 
         else:
 
-            def import_func(x, import_name, **kwargs):
+            def import_func2(x, import_name, **kwargs):
                 getattr(x.ss, f"pack_{import_name}")(**kwargs)
                 return x
 
         d["format"] = import_format
-        other = import_func(w2, import_name, take_ownership=take_ownership, **d)
+        other = import_func2(w2, import_name, take_ownership=take_ownership, **d)
         assert other.isequal(w_orig)
         assert other.ss.is_iso is do_iso
         d["format"] = "bad_format"
         with pytest.raises(ValueError, match="Invalid format"):
-            import_func(w2, import_name, **d)
+            import_func2(w2, import_name, **d)
     assert w.isequal(w_orig)
     assert w.ss.is_iso is do_iso
     assert w_orig.ss.is_iso is do_iso
@@ -1353,7 +1371,7 @@ def test_wait(v):
     assert v2.isequal(v)
     v2.wait("materialize")
     v2.wait("complete")
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match="`how` argument must be"):
         v2.wait("badmode")
 
 
@@ -1393,6 +1411,7 @@ def test_vector_index_with_scalar():
             v[s]
 
 
+@autocompute
 def test_diag(v):
     indices, values = v.to_coo()
     for k in range(-5, 5):
@@ -1599,6 +1618,7 @@ def test_expr_is_like_vector(v):
         "clear",
         "from_coo",
         "from_dict",
+        "from_pairs",
         "from_values",
         "resize",
         "update",
@@ -1610,6 +1630,16 @@ def test_expr_is_like_vector(v):
         "methods, then you may need to run `python -m graphblas.core.infixmethods`."
     )
     assert attrs - infix_attrs == expected
+    # Make sure signatures actually match
+    skip = {"__init__", "__repr__", "_repr_html_", "new"}
+    for expr in [binary.times(w & w), w & w]:
+        print(type(expr).__name__)
+        for attr, val in inspect.getmembers(expr):
+            if attr in skip or not isinstance(val, types.MethodType) or not hasattr(w, attr):
+                continue
+            val2 = getattr(w, attr)
+            assert inspect.signature(val) == inspect.signature(val2), attr
+            assert val.__doc__ == val2.__doc__
 
 
 @autocompute
@@ -1635,6 +1665,7 @@ def test_index_expr_is_like_vector(v):
         "clear",
         "from_coo",
         "from_dict",
+        "from_pairs",
         "from_values",
         "resize",
     }
@@ -1644,6 +1675,35 @@ def test_index_expr_is_like_vector(v):
         "and then run `python -m graphblas.core.automethods`.  If you're messing with infix "
         "methods, then you may need to run `python -m graphblas.core.infixmethods`."
     )
+    # Make sure signatures actually match. `update` has different docstring.
+    skip = {"__call__", "__init__", "__repr__", "_repr_html_", "new", "update"}
+    for attr, val in inspect.getmembers(w[[0, 1]]):
+        if attr in skip or not isinstance(val, types.MethodType) or not hasattr(w, attr):
+            continue
+        val2 = getattr(w, attr)
+        assert inspect.signature(val) == inspect.signature(val2), attr
+        assert val.__doc__ == val2.__doc__
+
+
+@autocompute
+def test_dup_expr(v):
+    result = (v + v).dup()
+    assert result.isequal(2 * v)
+    result = (v + v).dup(clear=True)
+    assert result.isequal(v.dup(clear=True))
+    result = (v * v).dup(mask=v.V)
+    assert result.isequal((v**2).new(mask=v.V))
+    result = v[:].dup()
+    assert result.isequal(v)
+    result = v[:].dup(clear=True)
+    assert result.isequal(v.dup(clear=True), check_dtype=True)
+    result = v[:].dup(float, clear=True)
+    assert result.isequal(v.dup(float, clear=True), check_dtype=True)
+    b = v.dup(bool)
+    result = (b | b).dup()
+    assert result.isequal(b)
+    result = (b | b).dup(clear=True)
+    assert result.isequal(b.dup(clear=True))
 
 
 @pytest.mark.skipif("not suitesparse")
@@ -1677,7 +1737,7 @@ def test_ss_random(v):
         r = v.ss.selectk("random", k)
         assert r.nvals == k
         assert monoid.any(v & r).new().nvals == k
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match="`how` argument must be one of"):
         v.ss.selectk("bad", 1)
 
 
@@ -1692,7 +1752,7 @@ def test_ss_firstk(v):
             x = w.ss.selectk("first", k)
             expected = Vector.from_coo(data[0][:k], data[1][:k], size=w.size)
             assert x.isequal(expected)
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match="negative k is not allowed"):
         v.ss.selectk("first", -1)
 
 
@@ -1836,7 +1896,7 @@ def test_ss_compactify(do_iso):
                 compare(v, w, size=i, asindex=asindex, sort=sort)
                 if not do_iso:
                     compare(v, w, size=i, asindex=asindex, isequal=True, sort=sort)
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match="`how` argument must be one of"):
         v.ss.compactify("bad_how")
 
 
@@ -1988,25 +2048,28 @@ def test_udt():
     assert v[:].new().isequal(v)
     indices, values = v.to_coo()
     assert v.isequal(Vector.from_coo(indices, values))
-    result = unary.positioni(v).new()
-    expected = Vector.from_coo([0, 1, 2], [0, 1, 2])
-    assert result.isequal(expected)
-    result = binary.firsti(v & v).new()
-    assert result.isequal(expected)
-    result = semiring.min_firsti(v @ v).new()
-    assert result == 0
     assert v.reduce(agg.any_value).new() == s
-    assert v.reduce(agg.first).new() == s
-    assert v.reduce(agg.last).new() == s
     assert v.reduce(agg.exists).new() == 1
-    assert v.reduce(agg.first_index).new() == 0
-    assert v.reduce(agg.last_index).new() == 2
     assert v.reduce(agg.count).new() == 3
     if suitesparse:
+        result = unary.ss.positioni(v).new()
+        expected = Vector.from_coo([0, 1, 2], [0, 1, 2])
+        assert result.isequal(expected)
+        assert v.reduce(agg.ss.first).new() == s
+        assert v.reduce(agg.ss.last).new() == s
+        assert v.reduce(agg.ss.first_index).new() == 0
+        assert v.reduce(agg.ss.last_index).new() == 2
+        result = binary.ss.firsti(v & v).new()
+        assert result.isequal(expected)
+        result = semiring.ss.min_firsti(v @ v).new()
+        assert result == 0
         info = v.ss.export()
         result = Vector.ss.import_any(**info)
         assert result.isequal(v)
-    for aggop in [agg.any_value, agg.first, agg.last, agg.count, agg.first_index, agg.last_index]:
+    aggs = [agg.any_value, agg.count]
+    if suitesparse:
+        aggs.extend([agg.ss.first, agg.ss.last, agg.ss.first_index, agg.ss.last_index])
+    for aggop in aggs:
         v.reduce(aggop).new()
     v.clear()
     v[[0, 1]] = [(2, 3), (4, 5)]
@@ -2068,7 +2131,10 @@ def test_udt():
     assert s == t
     assert t == s
     # Just make sure these work
-    for aggop in [agg.any_value, agg.first, agg.last, agg.count, agg.first_index, agg.last_index]:
+    aggs = [agg.any_value, agg.count]
+    if suitesparse:
+        aggs.extend([agg.ss.first, agg.ss.last, agg.ss.first_index, agg.ss.last_index])
+    for aggop in aggs:
         v.reduce(aggop).new()
     v.clear()
     v[[0, 1]] = [[2, 3, 4], [5, 6, 7]]
@@ -2091,7 +2157,7 @@ def test_udt():
     if suitesparse:
         vv = Vector.ss.deserialize(v.ss.serialize(), dtype=long_udt)
         assert v.isequal(vv, check_dtype=True)
-        with pytest.raises(Exception):
+        with pytest.raises(SyntaxError):
             # The size of the UDT name is limited
             Vector.ss.deserialize(v.ss.serialize())
     # May be able to look up non-anonymous dtypes by name if their names are too long
@@ -2137,9 +2203,9 @@ def test_infix_outer():
 @pytest.mark.skipif("not suitesparse")
 def test_ss_iteration(v):
     w = Vector(int, 2)
-    assert list(w.ss.iterkeys()) == []
-    assert list(w.ss.itervalues()) == []
-    assert list(w.ss.iteritems()) == []
+    assert not list(w.ss.iterkeys())
+    assert not list(w.ss.itervalues())
+    assert not list(w.ss.iteritems())
 
     indices, values = v.to_coo()
     # This is what I would expect
@@ -2332,7 +2398,7 @@ def test_get(v):
     assert v.get(1) == 1
     assert v.get(1, "mittens") == 1
     assert type(compute(v.get(1))) is int
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match="Bad index in Vector.get"):
         # Not yet supported
         v.get([0, 1])
 
@@ -2372,7 +2438,7 @@ def test_ss_config(v):
     assert v.ss.config == d
     for key, val in d.items():
         if key in v.ss.config._read_only:
-            with pytest.raises(ValueError):
+            with pytest.raises(ValueError, match="Config option .* is read-only"):
                 v.ss.config[key] = val
         else:
             v.ss.config[key] = val
@@ -2404,6 +2470,23 @@ def test_to_dict(v):
     assert empty.to_dict() == {}
 
 
+def test_from_pairs():
+    w = Vector.from_pairs([[0, 1], [2, 3]])
+    expected = Vector.from_coo([0, 2], [1, 3])
+    assert w.isequal(expected, check_dtype=True)
+    with pytest.raises(TypeError, match="use `Vector.from_coo`"):
+        Vector.from_pairs(np.array([[0, 1], [2, 3]], dtype=np.int64))
+
+    w = Vector.from_pairs([], size=4)
+    expected = Vector(float, size=4)
+    assert w.isequal(expected, check_dtype=True)
+
+    with pytest.raises(ValueError, match="Unable to infer size"):
+        Vector.from_pairs([])
+    with pytest.raises(ValueError, match="Each item in the pair"):
+        Vector.from_pairs([[1, 2, 3], [4, 5, 6]])
+
+
 @pytest.mark.skipif("not suitesparse")
 def test_ss_sort(v):
     # For equal values, indices are guaranteed to be sorted
